USE testdb;

DROP TABLE IF EXISTS testtbl;

CREATE TABLE testtbl
(
	abool ENUM('N', 'Y') NULL,
	sbyte TINYINT NULL,
	ubyte TINYINT UNSIGNED NULL,
	sshort SMALLINT NULL,
	ushort SMALLINT UNSIGNED NULL,
	sint INTEGER NULL,
	uint INTEGER UNSIGNED NULL,
	slong BIGINT NULL,
	ulong BIGINT UNSIGNED NULL,
	sfloat FLOAT NULL,
	ufloat FLOAT UNSIGNED NULL,
	sdouble DOUBLE NULL,
	udouble DOUBLE UNSIGNED NULL,
	slngdbl NUMERIC(14, 2) NULL,
	ulngdbl NUMERIC(14, 2) UNSIGNED NULL,
	astring1 CHAR(10) NULL,
	astring2 VARCHAR(10) NULL,
	adate DATE NULL,
	atime TIME NULL,
	atimestamp TIMESTAMP(3) NULL,
	abinary VARBINARY(18) NULL,
	aclob TEXT NULL,
	ablob BLOB NULL
);

DESCRIBE testtbl;

INSERT INTO testtbl VALUES
(
	'Y',
	-1,
	200,
	-1024,
	1024,
	-65536,
	65536,
	-8000000000,
	8000000000,
	-3.1416,
	3.1416,
	-123456.78,
	123456.78,
	-1234567890.12,
	1234567890.12,
	'telstra',
	'telstra',
	'2012-11-09',
	'12:41:15',
	'2012-11-09 12:43:30.125',
	0xC389,
	'The quick brown fox jumps over the lazy dog near the bank of the river.',
	0x01000000000000000000020000000000000000000300000000000000000004000000000000000000
);

INSERT INTO testtbl VALUES
(
	'N',
	1,
	2,
	3,
	4,
	5,
	6,
	7,
	8,
	9.0,
	10.0,
	11.0,
	12.0,
	13.0,
	14.0,
	'Leo',
	'Tess',
	'2012-11-09',
	'19:02:00',
	'2012-11-09 19:02:00.456',
	0xC3A7,
	'ODBC C data types indicate the data type of C buffers used to store data in the application.',
	0x01FFFFFFFFFFFFFFFFFF02FFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFF04FFFFFFFFFFFFFFFFFF
);

SELECT
	abool,
	sbyte,
	ubyte,
	sshort,
	ushort,
	sint,
	uint,
	slong,
	ulong,
	sfloat,
	ufloat,
	sdouble,
	udouble,
	slngdbl,
	ulngdbl,
	astring1,
	astring2,
	adate,
	atime,
	atimestamp,
	HEX(abinary) AS abinary,
	aclob,
	HEX(ablob) AS ablob
	FROM testtbl;

DROP PROCEDURE IF EXISTS test_in_out_1;

DELIMITER //

CREATE PROCEDURE test_in_out_1(val1 ENUM('N', 'Y'), OUT val2 ENUM('N', 'Y'))
BEGIN
	SELECT abool INTO val2 FROM testtbl WHERE abool = val1;
END //

DELIMITER ;

EXIT
